==> empathy_3.8.6.orig.tar.xz: empathy-3.8.6/libempathy-gtk/empathy-irc-network-chooser.h <==
/*
 * Copyright (C) 2007-2008 Guillaume Desmottes
 * Copyright (C) 2010 Collabora Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Authors: Guillaume Desmottes <gdesmott@gnome.org>
 */

#ifndef __EMPATHY_IRC_NETWORK_CHOOSER_H__
#define __EMPATHY_IRC_NETWORK_CHOOSER_H__

#include <gtk/gtk.h>

#include <libempathy/empathy-account-settings.h>
#include <libempathy/empathy-irc-network.h>

G_BEGIN_DECLS

#define EMPATHY_TYPE_IRC_NETWORK_CHOOSER (empathy_irc_network_chooser_get_type ())
#define EMPATHY_IRC_NETWORK_CHOOSER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), \
    EMPATHY_TYPE_IRC_NETWORK_CHOOSER, EmpathyIrcNetworkChooser))
#define EMPATHY_IRC_NETWORK_CHOOSER_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), \
    EMPATHY_TYPE_IRC_NETWORK_CHOOSER, EmpathyIrcNetworkChooserClass))
#define EMPATHY_IS_IRC_NETWORK_CHOOSER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), \
    EMPATHY_TYPE_IRC_NETWORK_CHOOSER))
#define EMPATHY_IS_IRC_NETWORK_CHOOSER_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), \
    EMPATHY_TYPE_IRC_NETWORK_CHOOSER))
#define EMPATHY_IRC_NETWORK_CHOOSER_GET_CLASS(o) ( \
    G_TYPE_INSTANCE_GET_CLASS ((o), EMPATHY_TYPE_IRC_NETWORK_CHOOSER, \
        EmpathyIrcNetworkChooserClass))

typedef struct {
  GtkButton parent;

  /*<private>*/
  gpointer priv;
} EmpathyIrcNetworkChooser;

typedef struct {
  GtkButtonClass parent_class;
} EmpathyIrcNetworkChooserClass;

GType empathy_irc_network_chooser_get_type (void) G_GNUC_CONST;

GtkWidget * empathy_irc_network_chooser_new (EmpathyAccountSettings *settings);

EmpathyIrcNetwork * empathy_irc_network_chooser_get_network (
    EmpathyIrcNetworkChooser *self);

G_END_DECLS

#endif /* __EMPATHY_IRC_NETWORK_CHOOSER_H__ */

==> empathy-3.9.3.tar.xz: empathy-3.9.3/libempathy-gtk/empathy-irc-network-chooser.h <==
/*
 * Copyright (C) 2007-2008 Guillaume Desmottes
 * Copyright (C) 2010 Collabora Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * Authors: Guillaume Desmottes <gdesmott@gnome.org>
 */

#ifndef __EMPATHY_IRC_NETWORK_CHOOSER_H__
#define __EMPATHY_IRC_NETWORK_CHOOSER_H__

#include <gtk/gtk.h>

#include "empathy-account-settings.h"
#include "empathy-irc-network.h"

G_BEGIN_DECLS

#define EMPATHY_TYPE_IRC_NETWORK_CHOOSER (empathy_irc_network_chooser_get_type ())
#define EMPATHY_IRC_NETWORK_CHOOSER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), \
    EMPATHY_TYPE_IRC_NETWORK_CHOOSER, EmpathyIrcNetworkChooser))
#define EMPATHY_IRC_NETWORK_CHOOSER_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), \
    EMPATHY_TYPE_IRC_NETWORK_CHOOSER, EmpathyIrcNetworkChooserClass))
#define EMPATHY_IS_IRC_NETWORK_CHOOSER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), \
    EMPATHY_TYPE_IRC_NETWORK_CHOOSER))
#define EMPATHY_IS_IRC_NETWORK_CHOOSER_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), \
    EMPATHY_TYPE_IRC_NETWORK_CHOOSER))
#define EMPATHY_IRC_NETWORK_CHOOSER_GET_CLASS(o) ( \
    G_TYPE_INSTANCE_GET_CLASS ((o), EMPATHY_TYPE_IRC_NETWORK_CHOOSER, \
        EmpathyIrcNetworkChooserClass))

typedef struct {
  GtkButton parent;

  /*<private>*/
  gpointer priv;
} EmpathyIrcNetworkChooser;

typedef struct {
  GtkButtonClass parent_class;
} EmpathyIrcNetworkChooserClass;

GType empathy_irc_network_chooser_get_type (void) G_GNUC_CONST;

GtkWidget * empathy_irc_network_chooser_new (EmpathyAccountSettings *settings);

EmpathyIrcNetwork * empathy_irc_network_chooser_get_network (
    EmpathyIrcNetworkChooser *self);

G_END_DECLS

#endif /* __EMPATHY_IRC_NETWORK_CHOOSER_H__ */
